==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/chr.pl <==
{
  am_pm_abbreviated => [
    "\N{U+13cc}\N{U+13be}\N{U+13b4}",
    "\N{U+13d2}\N{U+13af}\N{U+13f1}\N{U+13a2}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} w \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} Y",
    "yw-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} w \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} Y",
  },
  code => "chr",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} \N{U+13a4}\N{U+13be}\N{U+13a2} {0}",
  datetime_format_long => "{1} \N{U+13a4}\N{U+13be}\N{U+13a2} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}",
    "\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_format_narrow => [
    "\N{U+13c9}",
    "\N{U+13d4}",
    "\N{U+13e6}",
    "\N{U+13c5}",
    "\N{U+13e7}",
    "\N{U+13a4}",
    "\N{U+13c6}",
  ],
  day_format_wide => [
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}\N{U+13b6}\N{U+13cd}\N{U+13d7}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}",
    "\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_stand_alone_narrow => [
    "\N{U+13c9}",
    "\N{U+13d4}",
    "\N{U+13e6}",
    "\N{U+13c5}",
    "\N{U+13e7}",
    "\N{U+13a4}",
    "\N{U+13c6}",
  ],
  day_stand_alone_wide => [
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}\N{U+13b6}\N{U+13cd}\N{U+13d7}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "\N{U+13e7}\N{U+13d3}\N{U+13b7}\N{U+13b8} \N{U+13a4}\N{U+13b7}\N{U+13af}\N{U+13cd}\N{U+13d7} \N{U+13a6}\N{U+13b6}\N{U+13c1}\N{U+13db}",
    "\N{U+13a0}\N{U+13c3} \N{U+13d9}\N{U+13bb}\N{U+13c2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Cherokee",
  month_format_abbreviated => [
    "\N{U+13a4}\N{U+13c3}",
    "\N{U+13a7}\N{U+13a6}",
    "\N{U+13a0}\N{U+13c5}",
    "\N{U+13a7}\N{U+13ec}",
    "\N{U+13a0}\N{U+13c2}",
    "\N{U+13d5}\N{U+13ad}",
    "\N{U+13ab}\N{U+13f0}",
    "\N{U+13a6}\N{U+13b6}",
    "\N{U+13da}\N{U+13b5}",
    "\N{U+13da}\N{U+13c2}",
    "\N{U+13c5}\N{U+13d3}",
    "\N{U+13a5}\N{U+13cd}",
  ],
  month_format_narrow => [
    "\N{U+13a4}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13d5}",
    "\N{U+13ab}",
    "\N{U+13a6}",
    "\N{U+13da}",
    "\N{U+13da}",
    "\N{U+13c5}",
    "\N{U+13a5}",
  ],
  month_format_wide => [
    "\N{U+13a4}\N{U+13c3}\N{U+13b8}\N{U+13d4}\N{U+13c5}",
    "\N{U+13a7}\N{U+13a6}\N{U+13b5}",
    "\N{U+13a0}\N{U+13c5}\N{U+13f1}",
    "\N{U+13a7}\N{U+13ec}\N{U+13c2}",
    "\N{U+13a0}\N{U+13c2}\N{U+13cd}\N{U+13ac}\N{U+13d8}",
    "\N{U+13d5}\N{U+13ad}\N{U+13b7}\N{U+13f1}",
    "\N{U+13ab}\N{U+13f0}\N{U+13c9}\N{U+13c2}",
    "\N{U+13a6}\N{U+13b6}\N{U+13c2}",
    "\N{U+13da}\N{U+13b5}\N{U+13cd}\N{U+13d7}",
    "\N{U+13da}\N{U+13c2}\N{U+13c5}\N{U+13d7}",
    "\N{U+13c5}\N{U+13d3}\N{U+13d5}\N{U+13c6}",
    "\N{U+13a5}\N{U+13cd}\N{U+13a9}\N{U+13f1}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+13a4}\N{U+13c3}",
    "\N{U+13a7}\N{U+13a6}",
    "\N{U+13a0}\N{U+13c5}",
    "\N{U+13a7}\N{U+13ec}",
    "\N{U+13a0}\N{U+13c2}",
    "\N{U+13d5}\N{U+13ad}",
    "\N{U+13ab}\N{U+13f0}",
    "\N{U+13a6}\N{U+13b6}",
    "\N{U+13da}\N{U+13b5}",
    "\N{U+13da}\N{U+13c2}",
    "\N{U+13c5}\N{U+13d3}",
    "\N{U+13a5}\N{U+13cd}",
  ],
  month_stand_alone_narrow => [
    "\N{U+13a4}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13d5}",
    "\N{U+13ab}",
    "\N{U+13a6}",
    "\N{U+13da}",
    "\N{U+13da}",
    "\N{U+13c5}",
    "\N{U+13a5}",
  ],
  month_stand_alone_wide => [
    "\N{U+13a4}\N{U+13c3}\N{U+13b8}\N{U+13d4}\N{U+13c5}",
    "\N{U+13a7}\N{U+13a6}\N{U+13b5}",
    "\N{U+13a0}\N{U+13c5}\N{U+13f1}",
    "\N{U+13a7}\N{U+13ec}\N{U+13c2}",
    "\N{U+13a0}\N{U+13c2}\N{U+13cd}\N{U+13ac}\N{U+13d8}",
    "\N{U+13d5}\N{U+13ad}\N{U+13b7}\N{U+13f1}",
    "\N{U+13ab}\N{U+13f0}\N{U+13c9}\N{U+13c2}",
    "\N{U+13a6}\N{U+13b6}\N{U+13c2}",
    "\N{U+13da}\N{U+13b5}\N{U+13cd}\N{U+13d7}",
    "\N{U+13da}\N{U+13c2}\N{U+13c5}\N{U+13d7}",
    "\N{U+13c5}\N{U+13d3}\N{U+13d5}\N{U+13c6}",
    "\N{U+13a5}\N{U+13cd}\N{U+13a9}\N{U+13f1}",
  ],
  name => "Cherokee",
  native_language => "\N{U+13e3}\N{U+13b3}\N{U+13a9}",
  native_name => "\N{U+13e3}\N{U+13b3}\N{U+13a9}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "2nd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "3rd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "4th \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "2nd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "3rd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "4th \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/chr.pl <==
{
  am_pm_abbreviated => [
    "\N{U+13cc}\N{U+13be}\N{U+13b4}",
    "\N{U+13d2}\N{U+13af}\N{U+13f1}\N{U+13a2}",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, MMM d, y G",
    GyMMMd => "MMM d, y G",
    GyMd => "M/d/y GGGGG",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    "MMMMW-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
    "MMMMW-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} W \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} w \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} Y",
    "yw-count-other" => "\N{U+2019}\N{U+13d2}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13d7}\N{U+2019} w \N{U+2019}\N{U+13be}\N{U+13bf}\N{U+2019} Y",
  },
  code => "chr",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}",
    "\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_format_narrow => [
    "\N{U+13c9}",
    "\N{U+13d4}",
    "\N{U+13e6}",
    "\N{U+13c5}",
    "\N{U+13e7}",
    "\N{U+13a4}",
    "\N{U+13c6}",
  ],
  day_format_wide => [
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}\N{U+13b6}\N{U+13cd}\N{U+13d7}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}",
    "\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  day_stand_alone_narrow => [
    "\N{U+13c9}",
    "\N{U+13d4}",
    "\N{U+13e6}",
    "\N{U+13c5}",
    "\N{U+13e7}",
    "\N{U+13a4}",
    "\N{U+13c6}",
  ],
  day_stand_alone_wide => [
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c9}\N{U+13c5}\N{U+13af}",
    "\N{U+13d4}\N{U+13b5}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e6}\N{U+13a2}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13c5}\N{U+13a9}\N{U+13c1}\N{U+13a2}\N{U+13a6}",
    "\N{U+13e7}\N{U+13be}\N{U+13a9}\N{U+13b6}\N{U+13cd}\N{U+13d7}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c8}\N{U+13d5}\N{U+13be}",
    "\N{U+13a4}\N{U+13be}\N{U+13d9}\N{U+13d3}\N{U+13c6}\N{U+13cd}\N{U+13ac}",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "\N{U+13e7}\N{U+13d3}\N{U+13b7}\N{U+13b8} \N{U+13a4}\N{U+13b7}\N{U+13af}\N{U+13cd}\N{U+13d7} \N{U+13a6}\N{U+13b6}\N{U+13c1}\N{U+13db}",
    "\N{U+13a0}\N{U+13c3} \N{U+13d9}\N{U+13bb}\N{U+13c2}",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Cherokee",
  month_format_abbreviated => [
    "\N{U+13a4}\N{U+13c3}",
    "\N{U+13a7}\N{U+13a6}",
    "\N{U+13a0}\N{U+13c5}",
    "\N{U+13a7}\N{U+13ec}",
    "\N{U+13a0}\N{U+13c2}",
    "\N{U+13d5}\N{U+13ad}",
    "\N{U+13ab}\N{U+13f0}",
    "\N{U+13a6}\N{U+13b6}",
    "\N{U+13da}\N{U+13b5}",
    "\N{U+13da}\N{U+13c2}",
    "\N{U+13c5}\N{U+13d3}",
    "\N{U+13a5}\N{U+13cd}",
  ],
  month_format_narrow => [
    "\N{U+13a4}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13d5}",
    "\N{U+13ab}",
    "\N{U+13a6}",
    "\N{U+13da}",
    "\N{U+13da}",
    "\N{U+13c5}",
    "\N{U+13a5}",
  ],
  month_format_wide => [
    "\N{U+13a4}\N{U+13c3}\N{U+13b8}\N{U+13d4}\N{U+13c5}",
    "\N{U+13a7}\N{U+13a6}\N{U+13b5}",
    "\N{U+13a0}\N{U+13c5}\N{U+13f1}",
    "\N{U+13a7}\N{U+13ec}\N{U+13c2}",
    "\N{U+13a0}\N{U+13c2}\N{U+13cd}\N{U+13ac}\N{U+13d8}",
    "\N{U+13d5}\N{U+13ad}\N{U+13b7}\N{U+13f1}",
    "\N{U+13ab}\N{U+13f0}\N{U+13c9}\N{U+13c2}",
    "\N{U+13a6}\N{U+13b6}\N{U+13c2}",
    "\N{U+13da}\N{U+13b5}\N{U+13cd}\N{U+13d7}",
    "\N{U+13da}\N{U+13c2}\N{U+13c5}\N{U+13d7}",
    "\N{U+13c5}\N{U+13d3}\N{U+13d5}\N{U+13c6}",
    "\N{U+13a5}\N{U+13cd}\N{U+13a9}\N{U+13f1}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+13a4}\N{U+13c3}",
    "\N{U+13a7}\N{U+13a6}",
    "\N{U+13a0}\N{U+13c5}",
    "\N{U+13a7}\N{U+13ec}",
    "\N{U+13a0}\N{U+13c2}",
    "\N{U+13d5}\N{U+13ad}",
    "\N{U+13ab}\N{U+13f0}",
    "\N{U+13a6}\N{U+13b6}",
    "\N{U+13da}\N{U+13b5}",
    "\N{U+13da}\N{U+13c2}",
    "\N{U+13c5}\N{U+13d3}",
    "\N{U+13a5}\N{U+13cd}",
  ],
  month_stand_alone_narrow => [
    "\N{U+13a4}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13a7}",
    "\N{U+13a0}",
    "\N{U+13d5}",
    "\N{U+13ab}",
    "\N{U+13a6}",
    "\N{U+13da}",
    "\N{U+13da}",
    "\N{U+13c5}",
    "\N{U+13a5}",
  ],
  month_stand_alone_wide => [
    "\N{U+13a4}\N{U+13c3}\N{U+13b8}\N{U+13d4}\N{U+13c5}",
    "\N{U+13a7}\N{U+13a6}\N{U+13b5}",
    "\N{U+13a0}\N{U+13c5}\N{U+13f1}",
    "\N{U+13a7}\N{U+13ec}\N{U+13c2}",
    "\N{U+13a0}\N{U+13c2}\N{U+13cd}\N{U+13ac}\N{U+13d8}",
    "\N{U+13d5}\N{U+13ad}\N{U+13b7}\N{U+13f1}",
    "\N{U+13ab}\N{U+13f0}\N{U+13c9}\N{U+13c2}",
    "\N{U+13a6}\N{U+13b6}\N{U+13c2}",
    "\N{U+13da}\N{U+13b5}\N{U+13cd}\N{U+13d7}",
    "\N{U+13da}\N{U+13c2}\N{U+13c5}\N{U+13d7}",
    "\N{U+13c5}\N{U+13d3}\N{U+13d5}\N{U+13c6}",
    "\N{U+13a5}\N{U+13cd}\N{U+13a9}\N{U+13f1}",
  ],
  name => "Cherokee",
  native_language => "\N{U+13e3}\N{U+13b3}\N{U+13a9}",
  native_name => "\N{U+13e3}\N{U+13b3}\N{U+13a9}",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1st \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "2nd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "3rd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "4th \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1st \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "2nd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "3rd \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
    "4th \N{U+13a9}\N{U+13c4}\N{U+13d9}\N{U+13d7}",
  ],
  script => undef,
  territory => undef,
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 42,
}
